@@ -5,6 +5,7 @@ This module is not part of the pyrana public API.
 
 from functools import wraps
 import ctypes
+import platform
 import os
 import os.path
 import glob
@@ -97,7 +98,7 @@ class HLoader(object):
         find the most suitable (nearest compatible to the available
         major version) pseudo headers and returns them as list.
         """
-        libs = [ 'avutil', 'avcodec', 'avformat', 'swscale', 'swresample' ]
+        libs = ['avutil', 'avcodec', 'avformat', 'swscale', 'swresample']
         hnames = []
         for name, (major, minor, micro) in zip(libs, vertuples):
             hfile = self._hpath('%s%i.h' % (name, major))
@@ -115,21 +116,37 @@ class HLoader(object):
         self._vers = vers
 
 
+def _try_to_load(lib, vers):
+    """
+    load the first found version of the given library,
+    from most recent to less recent.
+    """
+    tmpl = _library_name()
+    for ver in vers:
+        try:
+            return ctypes.CDLL(tmpl % (lib, ver))
+        except OSError:
+            continue
+    msg = "cannot find a supported %s (supported versions: %s)" % (
+          lib, str(tuple(vers)))
+    raise LibraryVersionError(msg)
+
+
 def versions():
     """
     fetch the version of the FFMpeg libraries.
     """
-    lavu = ctypes.CDLL('libavutil.so')
-    lavc = ctypes.CDLL('libavcodec.so')
-    lavf = ctypes.CDLL('libavformat.so')
-    sws = ctypes.CDLL('libswscale.so')
-    swr = ctypes.CDLL('libswresample.so')
-    return [ av_version_unpack(v)
-             for v in (lavu.avutil_version(),
-                       lavc.avcodec_version(),
-                       lavf.avformat_version(),
-                       sws.swscale_version(),
-                       swr.swresample_version()) ]
+    lavu = _try_to_load('avutil', (52, ))
+    lavc = _try_to_load('avcodec', (55, 54))
+    lavf = _try_to_load('avformat', (55, 54))
+    sws = _try_to_load('swscale', (2, ))
+    swr = _try_to_load('swresample', (0, ))
+    return [av_version_unpack(v)
+            for v in (lavu.avutil_version(),
+                      lavc.avcodec_version(),
+                      lavf.avformat_version(),
+                      sws.swscale_version(),
+                      swr.swresample_version())]
 
 
 @singleton
@@ -143,21 +160,24 @@ class FF(object):
 
     def __init__(self):
         # beware of singleton before to add parameters here
-        self._vers = versions()
+        tmpl = _library_name()
+        vers = versions()
+        self._vers = vers
         _hl = HLoader(self._vers)
         self.ffi = cffi.FFI()
         self.ffi.cdef(_hl.decls)
-        self.lavc = self.ffi.dlopen("avcodec")
-        self.lavf = self.ffi.dlopen("avformat")
-        self.lavu = self.ffi.dlopen("avutil")
-        self.sws = self.ffi.dlopen("swscale")
-        self.swr = self.ffi.dlopen("swresample")
+        lavu, lavc, lavf, sws, swr = vers
+        self.lavc = self.ffi.dlopen(tmpl % ("avcodec", lavc[0]))
+        self.lavf = self.ffi.dlopen(tmpl % ("avformat", lavf[0]))
+        self.lavu = self.ffi.dlopen(tmpl % ("avutil", lavu[0]))
+        self.sws = self.ffi.dlopen(tmpl % ("swscale", sws[0]))
+        self.swr = self.ffi.dlopen(tmpl % ("swresample", swr[0]))
 
     def setup(self):
         """
         initialize the FFMpeg libraries.
         """
-        # note: libav* already protects against multiple calls.
+        # note: libav* already protects itself against multiple calls.
         self.lavc.avcodec_register_all()
         self.lavf.av_register_all()
         return self.versions()
@@ -187,3 +207,9 @@ def setup():
     ffh = FF()
     ffh.setup()
     return ffh
+
+
+def _library_name(plat=platform):
+    return ('%s-%i.dll'
+            if plat.system() == 'Windows'
+            else 'lib%s.so.%i')
