@@ -161,6 +161,8 @@ typedef struct AVCodec {
 AVCodec *av_codec_next(const AVCodec *c);
 AVCodec *avcodec_find_decoder(enum AVCodecID id);
 AVCodec *avcodec_find_decoder_by_name(const char *name);
+AVCodec *avcodec_find_encoder(enum AVCodecID id);
+AVCodec *avcodec_find_encoder_by_name(const char *name);
 
 enum AVMediaType avcodec_get_type(enum AVCodecID codec_id);
 const char *avcodec_get_name(enum AVCodecID id);
@@ -184,3 +186,8 @@ int avcodec_decode_video2(AVCodecContext *avctx, AVFrame *picture,
 int avcodec_decode_audio4(AVCodecContext *avctx, AVFrame *frame,
                           int *got_frame_ptr,
                           const AVPacket *avpkt);
+
+int avcodec_encode_video2(AVCodecContext *avctx, AVPacket *avpkt,
+                          const AVFrame *frame, int *got_packet_ptr);
+int avcodec_encode_audio2(AVCodecContext *avctx, AVPacket *avpkt,
+                          const AVFrame *frame, int *got_packet_ptr);
