@@ -4,6 +4,7 @@ This module is not part of the pyrana public API.
 """
 
 from .packet import PKT_SIZE
+from .errors import UnsupportedError
 from . import ff
 
 
@@ -29,6 +30,9 @@ class Buffer(object):
     def __setitem__(self, key, value):
         self.data[key] = value
 
+    def __delitem__(self, key):
+        raise UnsupportedError("cannot delete items from Buffers")
+
     def __repr__(self):
         return "Buffer(%i)" % self._size
 
@@ -68,18 +72,18 @@ def _read(handle, buf, buf_size):
     return ret if ret is not None else -1
 
 
-# not yet needed
-#def _write(handle, buf, buf_size):
-#    """
-#    libavformat write callback. Actually: wrapper. Do not use directly.
-#    """
-#    ffh = ff.get_handle()
-#    dst = ffh.ffi.from_handle(handle)
-#    wbuf = ffh.ffi.buffer(buf, buf_size)
-#    dst.write(wbuf)
+def _write(handle, buf, buf_size):
+    """
+    libavformat write callback. Actually: wrapper. Do not use directly.
+    """
+    ffh = ff.get_handle()
+    dst = ffh.ffi.from_handle(handle)
+    wbuf = ffh.ffi.buffer(buf, buf_size)
+    ret = dst.write(wbuf)
+    return ret
 
 
-AVSEEK_SIZE  = 0x10000
+AVSEEK_SIZE = 0x10000
 AVSEEK_FORCE = 0x20000
 
 
@@ -95,7 +99,7 @@ def _seek(handle, offset, whence):
     return ret
 
 
-class IOSource(object):
+class IOBridge(object):
     """
     wraps the avio handling.
     A separate classe is advisable because
@@ -103,16 +107,20 @@ class IOSource(object):
     2. you need o propelry av_free the avio once done
     which is enough (it is?) to build a class.
     """
-    def __init__(self, src, seekable=True, bufsize=PKT_SIZE, delay_open=False):
+    def __init__(self, fh, readwrite=True, seekable=True,
+                 bufsize=PKT_SIZE, delay_open=False):
         self._ff = ff.get_handle()
         ffi = self._ff.ffi
+        self._rw = readwrite
+        self._fh = fh
         self.avio = ffi.NULL
         self._buf = Buffer(bufsize)
-        self._src = src
-        self._read = ffi.callback("int(void *, uint8_t *, int)", _read)
-        self._seek = ffi.NULL
+        read = ffi.callback("int(void *, uint8_t *, int)", _read)
+        write = ffi.callback("int(void *, uint8_t *, int)", _write)
+        seek = ffi.NULL
         if seekable:
-            self._seek = ffi.callback("int64_t(void *, int64_t, int)", _seek)
+            seek = ffi.callback("int64_t(void *, int64_t, int)", _seek)
+        self._refs = (read, write, seek)  # ensure the callbacks are ref'd
         if not delay_open:
             self.open()
 
@@ -120,7 +128,7 @@ class IOSource(object):
         self.close()
 
     def __repr__(self):
-        return "IOSource(src=None, seekable=%i)" % (self.seekable)
+        return "IOBridge(src=None, seekable=%i)" % (self.seekable)
 
     def _alloc_buf(self, size):
         """
@@ -137,22 +145,23 @@ class IOSource(object):
     @property
     def seekable(self):
         """
-        is this IOSource seek-enabled?
+        is this IOBridge seek-enabled?
         """
-        return self._seek != self._ff.ffi.NULL
+        return self._refs[-1] != self._ff.ffi.NULL  # XXX
 
     def open(self):
         """
         open (really: allocate) the underlying avio
         """
         ffi = self._ff.ffi
+        read, write, seek = self._refs
         self.avio = self._ff.lavf.avio_alloc_context(self._alloc_buf(PKT_SIZE),
                                                      PKT_SIZE,
-                                                     0,
-                                                     ffi.new_handle(self._src),
-                                                     self._read,
-                                                     ffi.NULL,
-                                                     self._seek)
+                                                     int(self._rw),
+                                                     ffi.new_handle(self._fh),
+                                                     read,
+                                                     write,
+                                                     seek)
 
     def close(self):
         """
@@ -160,3 +169,28 @@ class IOSource(object):
         """
         self._ff.lavu.av_free(self.avio)
         self.avio = self._ff.ffi.NULL
+
+
+def _seekable(streamable):
+    """
+    is the stream seekable? The opposite of streamable.
+    """
+    return not streamable
+
+
+def iosource(source, streaming, bufsize=PKT_SIZE, delay_open=False):
+    """
+    convenience function.
+    builds an IOBridge suitable as source of data.
+    """
+    return IOBridge(source, readwrite=False, seekable=_seekable(streaming),
+                    bufsize=bufsize, delay_open=delay_open)
+
+
+def iosink(sink, streaming, bufsize=PKT_SIZE, delay_open=False):
+    """
+    convenience function.
+    builds an IOBridge suitable as sink for data.
+    """
+    return IOBridge(sink, readwrite=True, seekable=_seekable(streaming),
+                    bufsize=bufsize, delay_open=delay_open)
