@@ -43,6 +43,20 @@ def _new_cpkt(ffh, size):
     return pkt
 
 
+@contextmanager
+def bind_packet(ffh, size=0):
+    """
+    allocates an AVPacket and cleans it up on exception.
+    """
+    try:
+        cpkt = _new_cpkt(ffh, size)
+        yield cpkt
+    except errors.PyranaError:
+        ffh.lavc.av_free_packet(cpkt)
+        raise
+    # otherwise the ownership *has* to be passed.
+
+
 @contextmanager
 def raw_packet(size):
     """
